/*
 *   (C) Copyright IBM Corp. 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *  Module: md multipath region mgr
 *  File: multipath.h
 */

#ifndef _MD_MULTIPATH_MGR_H_
#define _MD_MULTIPATH_MGR_H_

#define EVMS_Task_Rewrite_Superblock  (EVMS_Task_Plugin_Function+1)

#define MP_CREATE_OPTION_COUNT	0
#define MP_REWRITE_SB_OPTION_COUNT 0

#define VOL_MAX_NR_DISKS(v, info) (v->nr_disks > info->nr_disks) ? v->nr_disks : info->nr_disks;

#endif

